@@ -4,14 +4,14 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.6/7.6-30.js
- * @description 7.6 - SyntaxError expected: reserved words used as Identifier Names in UTF8: class (class)
+ * @path ch07/7.6/7.6-25.js
+ * @description 7.6 - SyntaxError expected: reserved words used as Identifier Names in UTF8: with (with)
  */
 
 
 function testcase() {
             try {
-                eval("var cla\u0073s = 123;");  
+                eval("var \u0077ith = 123;");  
                 return false;
             } catch (e) {
                 return e instanceof SyntaxError;  
