@@ -4,15 +4,20 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.3/15.3.5/15.3.5.4/15.3.5.4_2-8gs.js
- * @description Strict mode - checking access to strict function caller from non-strict function (Function constructor includes strict directive prologue)
+ * @path ch15/15.3/15.3.5/15.3.5.4/15.3.5.4_2-36gs.js
+ * @description Strict mode - checking access to strict function caller from non-strict function (FunctionDeclaration defined within an Anonymous FunctionExpression with a strict directive prologue)
  * @noStrict
  * @negative TypeError
  */
 
 
-var f = Function("\"use strict\";\nreturn gNonStrict();");
-f();
+(function () {
+    "use strict";
+    function f() {
+        return gNonStrict();
+    }
+    return f();
+})();
 
 
 function gNonStrict() {
