@@ -4,27 +4,23 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.17/15.4.4.17-7-c-ii-2.js
- * @description Array.prototype.some - callbackfn takes 3 arguments
+ * @path ch15/15.4/15.4.4/15.4.4.16/15.4.4.16-7-c-ii-2.js
+ * @description Array.prototype.every - callbackfn takes 3 arguments
  */
 
 
 function testcase() { 
  
-  function callbackfn(val, idx, obj)
+  function callbackfn(val, Idx, obj)
   {
     if(arguments.length === 3)   //verify if callbackfn was called with 3 parameters
-      return false;
-    else
-      return true;
+       return true;
   }
 
   var arr = [0,1,true,null,new Object(),"five"];
   arr[999999] = -6.6;
   
-  if(arr.some(callbackfn) === false)
+  if(arr.every(callbackfn) === true)
     return true;
-
-
  }
 runTestCase(testcase);
