@@ -4,8 +4,8 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.17/15.4.4.17-7-c-i-4.js
- * @description Array.prototype.some - element to be retrieved is own data property that overrides an inherited data property on an Array
+ * @path ch15/15.4/15.4.4/15.4.4.19/15.4.4.19-8-c-i-4.js
+ * @description Array.prototype.map - element to be retrieved is own data property that overrides an inherited data property on an Array
  */
 
 
@@ -23,7 +23,9 @@ function testcase() {
         try {
             Array.prototype[0] = 11;
 
-            return [kValue].some(callbackfn);
+            var testResult = [kValue].map(callbackfn);
+
+            return testResult[0] === true;
         } finally {
             delete Array.prototype[0];
         }
