@@ -4,19 +4,20 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.4/15.4.4/15.4.4.19/15.4.4.19-8-c-ii-9.js
- * @description Array.prototype.map - callbackfn with 0 formal parameter
+ * @path ch15/15.4/15.4.4/15.4.4.22/15.4.4.22-9-c-ii-9.js
+ * @description Array.prototype.reduceRight - callbackfn is called with 0 formal parameter
  */
 
 
 function testcase() {
 
+        var called = 0;
+
         function callbackfn() {
+            called++;
             return true;
         }
 
-        var testResult = [11].map(callbackfn);
-
-        return testResult[0] === true;
+        return [11, 12].reduceRight(callbackfn, 11) === true && 2 === called;
     }
 runTestCase(testcase);
